/******************************************************************************
 * (c) Copyright 2007, 1060 Research Ltd
 *
 * This Software is licensed to You, the licensee, for use under the terms of
 * the 1060 Public License v1.0. Please read and agree to the 1060 Public
 * License v1.0 [www.1060research.com/license] before using or redistributing
 * this software.
 *
 * In summary the 1060 Public license has the following conditions.
 * A. You may use the Software free of charge provided you agree to the terms
 * laid out in the 1060 Public License v1.0
 * B. You are only permitted to use the Software with components or applications
 * that provide you with OSI Certified Open Source Code [www.opensource.org], or
 * for which licensing has been approved by 1060 Research Limited.
 * You may write your own software for execution by this Software provided any
 * distribution of your software with this Software complies with terms set out
 * in section 2 of the 1060 Public License v1.0
 * C. You may redistribute the Software provided you comply with the terms of
 * the 1060 Public License v1.0 and that no warranty is implied or given.
 * D. If you find you are unable to comply with this license you may seek to
 * obtain an alternative license from 1060 Research Limited by contacting
 * license@1060research.com or by visiting www.1060research.com
 *
 * NO WARRANTY:  THIS SOFTWARE IS NOT COVERED BY ANY WARRANTY. SEE 1060 PUBLIC
 * LICENSE V1.0 FOR DETAILS
 *
 * THIS COPYRIGHT NOTICE IS *NOT* THE 1060 PUBLIC LICENSE v1.0. PLEASE READ
 * THE DISTRIBUTED 1060_Public_License.txt OR www.1060research.com/license
 *
 * File:          $RCSfile: Packer.java,v $
 * Version:       $Name:  $ $Revision: 1.1 $
 * Last Modified: $Date: 2007/05/10 14:23:14 $
 *****************************************************************************/
package org.netkernel.packge.util;

import java.util.zip.*;
import java.io.*;
import java.net.*;

/**
 * Zip Packaging Utilities
 * @author  pjr
 */
public class ZipUtils {
	
	public static void zipDir(File zipDir, ZipOutputStream zos) throws Exception
	{	zipDir(zipDir,zos, null, "");
	}
	
	public static void zipDir(File zipDir, ZipOutputStream zos, URI base, String offset) throws Exception
	{	if(!zipDir.isHidden())
		{
			if(base==null)
			{	base=zipDir.toURI();
			}
			String[] dirList = zipDir.list(); 
			byte[] readBuffer = new byte[2156]; 
			int bytesIn = 0; 
			for(int i=0; i<dirList.length; i++) 
			{ 
				File f = new File(zipDir, dirList[i]); 
				if(f.isDirectory()) 
				{	String filePath = f.getPath(); 
					zipDir(new File(filePath), zos, base, offset); 
					continue; 
				} 
				FileInputStream fis = new FileInputStream(f); 
				ZipEntry anEntry = new ZipEntry(offset+base.relativize(f.toURI()).toString()); 
				zos.putNextEntry(anEntry); 
				while((bytesIn = fis.read(readBuffer)) != -1) 
				{ 
					zos.write(readBuffer, 0, bytesIn); 
				} 
			   fis.close(); 
			}
		}
	}
	
	public static void zipFile(File zipFile, ZipOutputStream zos, String offset) throws Exception
	{	if(!zipFile.isHidden())
		{
			URI base=zipFile.getParentFile().toURI();
			FileInputStream fis = new FileInputStream(zipFile); 
			ZipEntry anEntry = new ZipEntry(offset+base.relativize(zipFile.toURI()).toString());
			byte[] readBuffer = new byte[2156]; 
			zos.putNextEntry(anEntry); 
			int bytesIn = 0; 
			while((bytesIn = fis.read(readBuffer)) != -1) 
			{ 	zos.write(readBuffer, 0, bytesIn); 
			}
			fis.close();
		}
	}
	
	public static void zipVirtual(String name, InputStream data, ZipOutputStream zos) throws Exception
	{	ZipEntry anEntry = new ZipEntry(name);
		byte[] readBuffer = new byte[2156]; 
		zos.putNextEntry(anEntry); 
		int bytesIn = 0; 
		while((bytesIn = data.read(readBuffer)) != -1) 
		{ 	zos.write(readBuffer, 0, bytesIn); 
		}
		data.close(); 
		zos.closeEntry();
	}
	
	public static void cleanup(File temp)
	{	temp.deleteOnExit();
	}
}